#
#    NetBilling v2 Database
#
# (C) 2003-2006, Michael Klimenko
#
# $Revision: 2.7 $
#

DROP TABLE IF EXISTS Client;
CREATE TABLE Client (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Sig CHAR(1) BINARY,
    ZONEID INTEGER NOT NULL DEFAULT 0,
    IPID INTEGER NOT NULL DEFAULT 0,
    RID INTEGER NOT NULL DEFAULT 0,
    SWID INTEGER NOT NULL DEFAULT 0,
    VLAN INTEGER NOT NULL DEFAULT 1,
    Mask INT UNSIGNED NOT NULL DEFAULT 0xFFFFFFFF,
    NAME CHAR(30) NOT NULL DEFAULT 'Client name',
    IP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    DefIP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    MAC CHAR(17) NOT NULL DEFAULT '00:00:00:00:00:00',
    Credit DECIMAL(14,8) NOT NULL DEFAULT 0,
    Discount TINYINT DEFAULT 0,
    MonthFee DECIMAL(9,2) NOT NULL DEFAULT 0,
    Active BIT NOT NULL DEFAULT 0,
    CanCredit BIT NOT NULL DEFAULT 0,
    Language VARCHAR(15),
    Foto VARCHAR(150),
    Comment VARCHAR(150),
    DogNo VARCHAR(20),
    UNIQUE INDEX XAKClientNAME (NAME)
);

DROP TABLE IF EXISTS User;
CREATE TABLE User (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Client_ID INTEGER NOT NULL REFERENCES Client(ID) ON DELETE CASCADE,
    Password VARCHAR(20),
    FIO VARCHAR(50),
    Address VARCHAR(80),
    Phone VARCHAR(20),
    Email VARCHAR(40),
    SendDayReport BIT NOT NULL DEFAULT 0,
    SendMonthReport BIT NOT NULL DEFAULT 0,
    UNIQUE INDEX XAKUser (FIO(10), Address, Phone)
);

DROP TABLE IF EXISTS Zone;
CREATE TABLE Zone (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Name VARCHAR(20) NOT NULL,
    Descr VARCHAR(150),
    Kbit BIGINT NOT NULL DEFAULT 0,
#    GIncl BIGINT NOT NULL DEFAULT 0,
    GIncl DECIMAL(7,2) DEFAULT 0,
    Abon BIGINT NOT NULL DEFAULT 0,
    PriceIn DECIMAL(11,4) NOT NULL DEFAULT 0,
    PriceOut DECIMAL(11,4) NOT NULL DEFAULT 0,
    OrderNum SMALLINT UNSIGNED NOT NULL,
    UNIQUE INDEX XAKOrderNum (OrderNum)
);

DROP TABLE IF EXISTS Traffic;
CREATE TABLE Traffic (
    Client_ID INTEGER NOT NULL REFERENCES Client(ID) ON DELETE CASCADE,
    Zone_ID INTEGER NOT NULL REFERENCES Zone(ID) ON DELETE CASCADE,
    Year SMALLINT NOT NULL,
    Month TINYINT NOT NULL,
    Day SMALLINT NOT NULL,
    Inbound BIGINT NOT NULL DEFAULT 0,
    Outbound BIGINT NOT NULL DEFAULT 0,
    CostIn DECIMAL(14,8) NOT NULL DEFAULT 0,
    CostOut DECIMAL(14,8) NOT NULL DEFAULT 0,
    PRIMARY KEY (Client_ID,Zone_ID,Year,Month,Day),
    INDEX XIETraffic (Year,Month,Day)
);

DROP TABLE IF EXISTS Address;
CREATE TABLE Address (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Zone_ID INTEGER NOT NULL REFERENCES Zone (ID) ON DELETE CASCADE,
    IP INT UNSIGNED NOT NULL DEFAULT 0,
    Mask INT UNSIGNED NOT NULL DEFAULT 0xFFFFFFFF,
    Neg BIT NOT NULL DEFAULT 0,
    UNIQUE INDEX XAKZone (Zone_ID,IP,Mask),
    INDEX XIENeg (Neg)
);

DROP TABLE IF EXISTS Port;
CREATE TABLE Port (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Address_ID INTEGER NOT NULL REFERENCES Address (ID) ON DELETE CASCADE,
    PortNum SMALLINT UNSIGNED NOT NULL
);

DROP TABLE IF EXISTS Income;
CREATE TABLE Income (
    Client_ID INTEGER NOT NULL REFERENCES Client (ID) ON DELETE CASCADE,
    PayTime DATETIME NOT NULL,
    Sum DECIMAL(9,2) NOT NULL DEFAULT 0,
    PRIMARY KEY (Client_ID,PayTime),
    INDEX XIEIncome (PayTime)
);

DROP TABLE IF EXISTS Outlay;
CREATE TABLE Outlay (
    Client_ID INTEGER NOT NULL REFERENCES Client(ID) ON DELETE CASCADE,
    PayTime DATETIME NOT NULL,
    Sum DECIMAL(9,2) NOT NULL DEFAULT 0,
    Descr VARCHAR(50),
    PRIMARY KEY (Client_ID,PayTime),
    INDEX XIEOutlay (PayTime)
);

DROP TABLE IF EXISTS Card;
CREATE TABLE Card (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Password VARCHAR(20),
    Sum DECIMAL(9,2) NOT NULL DEFAULT 0,
    GenTime DATETIME NOT NULL,
    INDEX XIECard (GenTime)
);

DROP TABLE IF EXISTS Log;
CREATE TABLE Log (
    Client_ID INTEGER NOT NULL REFERENCES Client(ID) ON DELETE CASCADE,
    EventTime DATETIME NOT NULL,
    Msg VARCHAR(150),
    INDEX XIELog (EventTime)
);

DROP TABLE IF EXISTS ClientIP;
CREATE TABLE ClientIP (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Client_ID INTEGER NOT NULL REFERENCES Client(ID) ON DELETE CASCADE,
    IP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    MAC CHAR(17) NOT NULL DEFAULT '00:00:00:00:00:00',
    UNIQUE INDEX XAKClientIP (IP)
);

DROP TABLE IF EXISTS Iface;
CREATE TABLE Iface (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    TRAFID INTEGER NOT NULL DEFAULT 0,
    Name VARCHAR(20) NOT NULL,
    Descr VARCHAR(150),
    PriceIn DECIMAL(11,4) NOT NULL DEFAULT 0,
    PriceOut DECIMAL(11,4) NOT NULL DEFAULT 0,
    OrderNum SMALLINT UNSIGNED NOT NULL,
    UNIQUE INDEX XAKOrderNum (OrderNum)
);

DROP TABLE IF EXISTS IfTraf;
CREATE TABLE IfTraf (
    Iface_ID INTEGER NOT NULL REFERENCES Iface(ID) ON DELETE CASCADE,
    Year SMALLINT NOT NULL,
    Month TINYINT NOT NULL,
    Inbound BIGINT NOT NULL DEFAULT 0,
    Outbound BIGINT NOT NULL DEFAULT 0,
    CostIn DECIMAL(14,8) NOT NULL DEFAULT 0,
    CostOut DECIMAL(14,8) NOT NULL DEFAULT 0,
    PRIMARY KEY (Iface_ID,Year,Month),
    INDEX XIEIfTraf (Year,Month)
);

DROP TABLE IF EXISTS IfAddr;
CREATE TABLE IfAddr (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Iface_ID INTEGER NOT NULL REFERENCES Iface(ID) ON DELETE CASCADE,
    IP INT UNSIGNED NOT NULL DEFAULT 0,
    Mask INT UNSIGNED NOT NULL DEFAULT 0xFFFFFFFF,
    Neg BIT NOT NULL DEFAULT 0,
    UNIQUE INDEX XAKIface (Iface_ID,IP,Mask),
    INDEX XIENeg (Neg)
);

DROP TABLE IF EXISTS Routers;
CREATE TABLE Routers (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Name VARCHAR(20) NOT NULL,
    IP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    Descr VARCHAR(100),
    Script VARCHAR(120),
    UNIQUE INDEX XAKRoutersName (Name)
);

DROP TABLE IF EXISTS Swiches;
CREATE TABLE Swiches (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Name VARCHAR(20) NOT NULL,
    IP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    Descr VARCHAR(100),
    Script VARCHAR(120),
    UNIQUE INDEX XAKSwichesName (Name)
);

DROP TABLE IF EXISTS SwPorts;
CREATE TABLE SwPorts (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Client_ID INTEGER NOT NULL REFERENCES Client(ID) ON DELETE CASCADE,
    Sw_ID INT UNSIGNED NOT NULL DEFAULT 0,
    Port VARCHAR(10),
    LinkDescr VARCHAR(20),
    UNIQUE INDEX XAKSwPortsClient_ID (Client_ID)
);

DROP TABLE IF EXISTS Nets;
CREATE TABLE Nets (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Mask INT UNSIGNED NOT NULL DEFAULT 0xFFFFFFFF,
    NAME CHAR(30) NOT NULL DEFAULT 'Client name',
    FirstIP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    LastIP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    NET CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    UNIQUE INDEX Nets_ID (ID)
);

DROP TABLE IF EXISTS SubNets;
CREATE TABLE SubNets (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    NetID INTEGER NOT NULL REFERENCES Nets(ID) ON DELETE CASCADE,
    Mask INT UNSIGNED NOT NULL DEFAULT 0xFFFFFFFF,
    NAME CHAR(30) NOT NULL DEFAULT 'Client name',
    DefIP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    FirstIP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    LastIP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    NET CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    RID INT UNSIGNED DEFAULT 0,
    Vlan INT UNSIGNED DEFAULT 1,
    SortN INT UNSIGNED DEFAULT 0,
    Used INT UNSIGNED DEFAULT 0,
    UNIQUE INDEX SubNets_ID (ID)
);

DROP TABLE IF EXISTS Works;
CREATE TABLE Works (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Time BIGINT NOT NULL DEFAULT 0,
    Action INT UNSIGNED NOT NULL DEFAULT 0,
    Router_ID INTEGER NOT NULL REFERENCES Routers(ID) ON DELETE CASCADE,
    Swich_ID INTEGER NOT NULL REFERENCES Swiches(ID) ON DELETE CASCADE,
    Client_ID INTEGER NOT NULL REFERENCES Client(ID) ON DELETE CASCADE,
    Zone_ID INTEGER NOT NULL REFERENCES Zone(ID) ON DELETE CASCADE,
    Client_IP CHAR(15) NOT NULL DEFAULT '0.0.0.0',
    UNIQUE INDEX Works_ID (ID)
);

DROP TABLE IF EXISTS Users;
CREATE TABLE Users (
    ID INTEGER UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    RefererID INTEGER UNSIGNED NOT NULL DEFAULT 0,
    DopInfoID INTEGER UNSIGNED NOT NULL DEFAULT 0,
    Login VARCHAR(30) NOT NULL DEFAULT '',
    Passw VARCHAR(90) NOT NULL DEFAULT '',
    AName VARCHAR(30) NOT NULL DEFAULT '',
    AFam VARCHAR(30) NOT NULL DEFAULT '',
    AOtc VARCHAR(30) NOT NULL DEFAULT '',
    Foto VARCHAR(150),
    Email VARCHAR(100) NOT NULL DEFAULT '',
    SubInfo VARCHAR(254) NOT NULL DEFAULT ' ',
    BirthDate INT UNSIGNED NOT NULL DEFAULT 0,
    CreateDate INT UNSIGNED NOT NULL DEFAULT 0,
    LastActive INT UNSIGNED NOT NULL DEFAULT 0,
    Status INT UNSIGNED NOT NULL DEFAULT 0,
    SendMail TINYINT DEFAULT 1,
    UNIQUE INDEX XAKUsersID (ID)
);

INSERT INTO Users (RefererID,Login,Passw,AName,AFam,AOtc,Foto,Email,SubInfo,Status,SendMail,CreateDate) VALUES (1, 'admin', 'ISMvKXpXpadDiUoOSoAfww', '', '', '', '', '', '  .       !', 2, 2, 1247746795 );

DROP TABLE IF EXISTS SwichD;
CREATE TABLE SwichD (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Swich_ID INTEGER NOT NULL REFERENCES Swiches(ID) ON DELETE CASCADE,
    Type TINYINT DEFAULT 0,
    Community VARCHAR(120),
    Parameters VARCHAR(120),
    Time INT UNSIGNED NOT NULL DEFAULT 0,
    Script VARCHAR(120),
    UNIQUE INDEX XAKSwichD_ID (ID)
);

DROP TABLE IF EXISTS PortData;
CREATE TABLE PortData (
    ID INTEGER AUTO_INCREMENT PRIMARY KEY,
    Swich_ID INTEGER NOT NULL REFERENCES Swiches(ID) ON DELETE CASCADE,
    Port INT UNSIGNED NOT NULL DEFAULT 0,
    U BIGINT NOT NULL DEFAULT 0,
    D BIGINT NOT NULL DEFAULT 0,
    UNIQUE INDEX XAKPortData_ID (ID)
);

